# vim: set sw=4 ts=4 et:

Summary:        Real-time MIDI input/output audio tools
Name:           portmidi
%define soname  0
Version:        217
Release:        3.2
License:        GNU General Public License version 2 or later (GPL v2 or later)
Group:          Productivity/Multimedia/Sound/Midi
# http://prdownloads.sourceforge.net/portmedia/portmidi-src-217.zip
Source0:        portmidi-src-%{version}.tar.bz2
Patch1:         portmidi-fix_build.patch
Patch2:         portmidi-fix_pmdefaults_startup_script.patch
Patch3:         portmidi-fix_java_cmake.patch
Source99:       portmidi-rpmlintrc
URL:            http://sourceforge.net/apps/trac/portmedia/wiki/portmidi
BuildRoot:      %{_tmppath}/%{name}-%{version}-buildroot
BuildRequires:  alsa-devel >= 0.9
BuildRequires:  cmake make gcc-c++ glibc-devel
BuildRequires:  java-devel
Requires:       libportmidi%{soname} = %{version}

%description
PortMidi -- real-time MIDI input/output.
This package contains some command-line applications to test, configure and use
midi devices through PortMidi.

%package -n libportmidi%{soname}
Summary:        Real-time MIDI input/output audio library
Group:          System/Libraries
%description -n libportmidi%{soname}
PortMidi -- a library for real-time MIDI input/output audio.
This package contains the shared library that is required at runtime for every
application that uses PortMidi.

%package devel
Summary:        Real-time MIDI input/output audio library
Group:          Development/Libraries/Other
Requires:       libportmidi%{soname} = %{version}
%description devel
PortMidi -- real-time MIDI input/output.
This package contains the development environment to build applications and
other libraries that use PortMidi.

%package java
Summary:        Java native bindings for %{name}
Group:          Development/Libraries/Java
Requires:       libportmidi%{soname} = %{version}
%description java
PortMidi -- real-time MIDI input/output.
This package contains bindings to use %{name} from Java.

%prep
%setup -q -n "%{name}"
%patch1
%patch2
%if 0%{?suse_version} >= 1200
%patch3
%endif

%__perl -ne 'print $1,"\n" if /^\+{3}\s+(.+)\s+\d{4}-\d{2}-\d{2}\s+/' <"%{PATCH2}" | while read f; do
    %__sed -i -e 's|@@JAVADIR@@|%{_javadir}|g' "$f"
done

find . -type f -name '*.txt' -exec %__chmod 0644 {} \;
find . -type f -name 'README*.txt' -exec %__sed -i -e 's/\r$//' {} \;

%build
LIBSUFFIX=$(echo "%{_lib}" | %__sed 's|^lib||')
%__mkdir_p inst/{bin,lib}
OD="$PWD/inst"

# don't use a "build" subdir, doesn't work
OPTFLAGS="%{optflags}" \
cmake \
    -DCMAKE_VERBOSE_MAKEFILE=TRUE \
    -DCMAKE_INSTALL_PREFIX:PATH="%{_prefix}" \
    -DBIN_INSTALL_DIR="%{_bindir}" \
    -DLIB_INSTALL_DIR="%{_libdir}" \
    -DINC_INSTALL_DIR="%{_includedir}" \
    -DLIB_SOVERSION="%{soname}" \
    -DLIB_VERSION="%{soname}.%{version}" \
    -DCMAKE_SKIP_RPATH=TRUE \
    -DCMAKE_BUILD_WITH_INSTALL_RPATH=FALSE \
    -DCMAKE_C_FLAGS_RELEASE:STRING="%{optflags}" \
    -DCMAKE_BUILD_TYPE=release \
    -DCMAKE_STRIP="/usr/bin/touch" \
    -DLIB_SUFFIX="$LIBSUFFIX" \
    -DCMAKE_RUNTIME_OUTPUT_DIRECTORY="$OD/bin" \
    -DCMAKE_LIBRARY_OUTPUT_DIRECTORY="$OD/lib" \
    -DCMAKE_ARCHIVE_OUTPUT_DIRECTORY="$OD/lib" \
    .

%__make ##%{?_smp_flags}

%install
%makeinstall

pushd inst/bin
for f in *; do
    [ -x "$f" ] || continue
    %__install -m0755 "$f" "%{buildroot}%{_bindir}/%{name}-$f"
done
popd #inst/bin

%clean
%{?buildroot:%{__rm} -rf %{buildroot}}

%post   -n libportmidi%{soname} -p /sbin/ldconfig
%postun -n libportmidi%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/pmdefaults
%{_bindir}/portmidi-latency
%{_bindir}/portmidi-mm
%{_bindir}/portmidi-midiclock
%{_bindir}/portmidi-midithread
%{_bindir}/portmidi-midithru
%{_bindir}/portmidi-sysex
%{_bindir}/portmidi-test
%{_bindir}/portmidi-qtest

%files -n libportmidi%{soname}
%defattr(-,root,root)
%doc README.txt pm_linux/README_LINUX.txt
%{_libdir}/libportmidi.so.%{soname}
%{_libdir}/libportmidi.so.%{soname}.%{version}

%files devel
%defattr(-,root,root)
%{_includedir}/portmidi.h
%{_includedir}/porttime.h
%{_libdir}/libportmidi_s.a
%{_libdir}/libportmidi.so

%files java
%defattr(-,root,root)
%{_libdir}/libpmjni.so
%{_javadir}/pmdefaults.jar

%changelog
* Tue Dec 27 2011 pascal.bleser@opensuse.org
- fix build on >= 12.1
* Sun Feb 27 2011 pascal.bleser@opensuse.org
- update to version 217
- complete spec file rewrite, moved to cmake
* Mon Nov 17 2008 joop.boonen@opensuse.org
- creating package in OBS
* Tue Apr  3 2007 nando@ccrma.stanford.edu
- add -fPIC flag for x86_64 build
* Sun Apr  1 2007 nando@ccrma.stanford.edu
- build on fc6
* Sat Nov 19 2005 nando@ccrma.stanford.edu
- added patch to link libporttime to the pthreads library, otherwise
  it can't be loaded independently of libportmidi
* Thu Nov 10 2005 nando@ccrma.stanford.edu
- added Debian patches to build shared libraries neede by Common Music
* Mon Nov  7 2005 nando@ccrma.stanford.edu
- first build for Planet CCRMA, from Thac's spec file
- just create "portmidi" (follow naming in Fedora for "portaudio")
- probably should add test programs
- todo: use Debian patches to make shared libraries...
* Wed Sep 28 2005 tobbe@nyvalls.se
- Fix spec
* Wed Sep  7 2005 tobbe@nyvalls.se
- Rebuilt for le2005
* Tue Aug 23 2005 oc2pus@arcor.de 20041117-0.oc2pus.2
- included patch from freecycle to avoid memory leak
* Wed Apr 20 2005 oc2pus@arcor.de 20041117-0.oc2pus.1
- initial build for SuSE
